==> beast-privilege-api-2.6.4-GS-20230104.095226-11-sources.jar: com/thebeastshop/privilege/vo/StoremanTaskmanagerVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2022/8/30.
 */
public class StoremanTaskmanagerVO implements Serializable {
    private Integer id;
    private String code;
    private String name;
    private Date startTime;
    private Date endTime;
    private Integer type;
    private String note;
    private Integer createId;
    private String createMan;
    private Date createTime;
    private String statusDesc;
    private String typeDesc;
    private List<StoremanTaskmanagerDetailVO> detailVOList;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public String getTypeDesc() {
        return typeDesc;
    }

    public void setTypeDesc(String typeDesc) {
        this.typeDesc = typeDesc;
    }

    public List<StoremanTaskmanagerDetailVO> getDetailVOList() {
        return detailVOList;
    }

    public void setDetailVOList(List<StoremanTaskmanagerDetailVO> detailVOList) {
        this.detailVOList = detailVOList;
    }


}

==> beast-privilege-api-3.0.11-GS-20250829.101401-7-sources.jar: com/thebeastshop/privilege/vo/StoremanTaskmanagerVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2022/8/30.
 */
public class StoremanTaskmanagerVO implements Serializable {
    private Integer id;
    private String code;
    private String name;
    private Date startTime;
    private Date endTime;
    private Integer type;
    private String note;
    private Integer createId;
    private String createMan;
    private Date createTime;
    private String statusDesc;
    private String typeDesc;

    private String channelCode;

    private String channelName;
    private List<StoremanTaskmanagerDetailVO> detailVOList;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public Integer getCreateId() {
        return createId;
    }

    public void setCreateId(Integer createId) {
        this.createId = createId;
    }

    public String getCreateMan() {
        return createMan;
    }

    public void setCreateMan(String createMan) {
        this.createMan = createMan;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public String getTypeDesc() {
        return typeDesc;
    }

    public void setTypeDesc(String typeDesc) {
        this.typeDesc = typeDesc;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }


    public List<StoremanTaskmanagerDetailVO> getDetailVOList() {
        return detailVOList;
    }

    public void setDetailVOList(List<StoremanTaskmanagerDetailVO> detailVOList) {
        this.detailVOList = detailVOList;
    }


}
